@@ -1,5 +1,5 @@
 /*
- * Copyright 2019-2020 PixlOne
+ * Copyright 2019-2023 PixlOne
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,17 +19,15 @@
 #ifndef LOGID_BACKEND_HIDPP10_DEFS_H
 #define LOGID_BACKEND_HIDPP10_DEFS_H
 
-namespace logid {
-namespace backend {
-namespace hidpp10
-{
-    enum SubID: uint8_t
-    {
+namespace logid::backend::hidpp10 {
+    enum SubID : uint8_t {
         SetRegisterShort = 0x80,
         GetRegisterShort = 0x81,
         SetRegisterLong = 0x82,
-        GetRegisterLong = 0x83
+        GetRegisterLong = 0x83,
     };
-}}}
+
+    static constexpr size_t SubIDCount = 4;
+}
 
 #endif //LOGID_BACKEND_HIDPP10_DEFS_H
\ No newline at end of file
